﻿IF  EXISTS (SELECT * FROM sys.objects WHERE object_id = OBJECT_ID(N'[dbo].[FNS_Contents_GetContentsForWidget]') AND type in (N'P', N'PC'))
DROP PROCEDURE [dbo].[FNS_Contents_GetContentsForWidget]
GO
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE PROCEDURE [dbo].[FNS_Contents_GetContentsForWidget]
(
	@productId int ,	--Product identifier
	@categoryId int,    --Category identifier
	@manufacturerId int,   --Manufacturer identifier
	@storeId			int, -- Store mapping
	@slugName nvarchar(400) --Slug name
)
AS
BEGIN
SET NOCOUNT ON

create table #ContentId (Id int)

create table #tmpFNS_Content (Id int, LimitedToStores bit, SubjectToAcl bit)

insert into #tmpFNS_Content(Id, LimitedToStores, SubjectToAcl)
select P.Id, P.LimitedToStores, P.SubjectToAcl
from FNS_Content P WITH (NOLOCK)
where P.Published=1 
	and getutcdate() BETWEEN isnull(P.DatenStartUtc, '1/1/1900') AND isnull(P.DatenEndUtc, '1/1/2999')

--Product
create table #ContentIdProduct (Id int)
if @productId>0 and exists(select G.CategoryId from Product_Category_Mapping G WITH (NOLOCK) where G.ProductId=@productId)
begin
		create table #CategoryId (Id int)

		--Category tree
		;with cte_tree (Id,ParentCategoryId) as 
		(
			select C.Id,C.ParentCategoryId
			from Category C WITH (NOLOCK)
			where C.Id in (select G.CategoryId from Product_Category_Mapping G WITH (NOLOCK) where G.ProductId=@productId)
				and C.Deleted=0 and C.Published=1
			union all
			select T.Id,T.ParentCategoryId
			from cte_tree C,Category T WITH (NOLOCK)
			where C.ParentCategoryId=T.Id and T.Deleted=0 and T.Published=1
		)
		
		insert into #CategoryId (Id)
		select Id
		from cte_tree

		insert into #ContentIdProduct (Id)
		select A.Id
		from FNS_ContentCategory AG WITH (NOLOCK),#tmpFNS_Content A WITH (NOLOCK)
		where AG.CategoryId in (select C.Id from #CategoryId C)
			and AG.ContentId=A.Id
		
		drop table #CategoryId
end

if @productId>0 and exists(select M.ManufacturerId from Product_Manufacturer_Mapping M WITH (NOLOCK) where M.ProductId=@productId)
begin
		insert into #ContentIdProduct (Id)
		select A.Id
		from FNS_ContentManufacturer AG WITH (NOLOCK),#tmpFNS_Content A WITH (NOLOCK)
		where AG.ManufacturerId in (select M.ManufacturerId from Product_Manufacturer_Mapping M WITH (NOLOCK) where M.ProductId=@productId)
			and AG.ContentId=A.Id
end

insert into #ContentIdProduct (Id)
select distinct A.Id
from #tmpFNS_Content A WITH (NOLOCK), 
	FNS_ContentProduct AP WITH (NOLOCK)
where A.Id not in (select Id from #ContentIdProduct)
	and A.Id=AP.ContentId and AP.ProductId=@productId
	
--Category
create table #ContentIdCategory (Id int)
if @categoryId>0
begin
		create table #CategoryId2 (Id int)

		--Category tree
		;with cte_tree2 (Id,ParentCategoryId) as 
		(
			select C.Id,C.ParentCategoryId
			from Category C WITH (NOLOCK)
			where C.Id=@categoryId
				and C.Deleted=0 and C.Published=1
			union all
			select T.Id,T.ParentCategoryId
			from cte_tree2 C,Category T WITH (NOLOCK)
			where C.ParentCategoryId=T.Id and T.Deleted=0 and T.Published=1
		)

		insert into #CategoryId2 (Id)		
		select Id
		from cte_tree2

		insert into #ContentIdCategory (Id)
		select A.Id
		from FNS_ContentCategory AG WITH (NOLOCK),#tmpFNS_Content A WITH (NOLOCK)
		where ((AG.CategoryId = @categoryId and AG.ForSubCategory=0)
				or (AG.ForSubCategory = 1 and AG.CategoryId in (select C.id from #CategoryId2 C))
				)
			and AG.ContentId=A.Id
			
		drop table #CategoryId2
end

--Manufacturer
create table #ContentIdManufacturer (Id int)

if @manufacturerId>0
begin
	insert into #ContentIdManufacturer (Id)
	select distinct A.Id
	from #tmpFNS_Content A WITH (NOLOCK), 
		FNS_ContentManufacturer AM WITH (NOLOCK)
	where A.Id=AM.ContentId and AM.ManufacturerId=@manufacturerId
end

--SlugName
create table #ContentIdSlug (Id int)
SET @slugName = rtrim(ltrim(isnull(@slugName, '')))

if len(@slugName)>0
begin
	insert into #ContentIdSlug (Id)
	select distinct A.Id
	from #tmpFNS_Content A WITH (NOLOCK), 
		FNS_ContentSlug AM WITH (NOLOCK)
	where A.Id=AM.ContentId and AM.Slug=@slugName
end


insert into #ContentId (Id)	
select Id
from (
	select Id
	from #ContentIdProduct
	union
	select Id
	from #ContentIdCategory
	union
	select Id
	from #ContentIdManufacturer
	union
	select Id
	from #ContentIdSlug
	) S

drop table #ContentIdProduct
drop table #ContentIdCategory
drop table #ContentIdManufacturer
drop table #ContentIdSlug

insert into #ContentId (Id)
select distinct A.Id
from #tmpFNS_Content A WITH (NOLOCK) 
where A.Id not in (select Id from #ContentId)
	and A.Id not in (select ContentId from FNS_ContentCategory WITH (NOLOCK))
	and A.Id not in (select ContentId from FNS_ContentProduct WITH (NOLOCK))
	and A.Id not in (select ContentId from FNS_ContentManufacturer WITH (NOLOCK))
	and A.Id not in (select ContentId from FNS_ContentSlug WITH (NOLOCK))

delete from #tmpFNS_Content where Id not in (select Id from #ContentId)
drop table #ContentId

if exists(select * from #tmpFNS_Content)			
begin
	--StoreMapping
	if exists(select Id from #tmpFNS_Content where LimitedToStores=1)		
	begin								
		delete #tmpFNS_Content
		from #tmpFNS_Content C
		where C.LimitedToStores!=0 and not Exists(select Top 1 Id from StoreMapping SM WITH (NOLOCK)
					where sm.EntityName = 'Content' and sm.StoreId=@storeId and sm.EntityId=C.Id)	
	end
	/*
    --ACL Content
	if exists(select Id from #tmpFNS_Content where SubjectToAcl=1)		
	begin
		--filter by customer role IDs (access control list)
		SET @AllowedCustomerRoleIds = isnull(@AllowedCustomerRoleIds, '')	
		CREATE TABLE #FilteredCustomerRoleIds
		(
			CustomerRoleId int not null
		)
	
		INSERT INTO #FilteredCustomerRoleIds (CustomerRoleId)
		SELECT CAST(data as int) FROM [nop_splitstring_to_table](@AllowedCustomerRoleIds, ',')	

		delete #tmpFNS_Content
		from #tmpFNS_Content C
		where C.SubjectToAcl=1 and not EXISTS (
								SELECT 1 FROM #FilteredCustomerRoleIds [fcr]
									WHERE
										[fcr].CustomerRoleId IN (
											SELECT [acl].CustomerRoleId
											FROM [AclRecord] acl  WITH (NOLOCK)
											WHERE [acl].EntityId = C.Id AND [acl].EntityName = 'Content'
										)
								)
		drop table #FilteredCustomerRoleIds
	end
	*/
end

select P.*
from FNS_Content P WITH (NOLOCK)
where P.Id in (select Id from #tmpFNS_Content)
order by P.DisplayOrder

drop table #tmpFNS_Content

END
GO
